@@ -18,7 +18,6 @@
 #include <QTextStream>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#include <KUserFeedback/FeedbackConfigWidget>
 #include <KUserFeedback/Provider>
 #endif
 
@@ -54,13 +53,14 @@ int main(int argc, char **argv)
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 #ifdef WITH_KUSERFEEDBACK
-    parser.addOption(QCommandLineOption(QStringLiteral("feedback"), i18n("Lists the available options for user feedback")));
+    const QCommandLineOption feedbackOption(QStringLiteral("feedback"), i18n("Lists the available options for user feedback"));
+    parser.addOption(feedbackOption);
 #endif
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
 #ifdef WITH_KUSERFEEDBACK
-    if (parser.isSet(QStringLiteral("feedback"))) {
+    if (parser.isSet(feedbackOption)) {
         QTextStream(stdout) << UserFeedBackManager::self()->userFeedbackProvider()->describeDataSources() << '\n';
         return 0;
     }
