@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,7 +36,7 @@ static QString authenticationModeString(MailTransport::Transport::EnumAuthentica
     default:
         break;
     }
-    return QString();
+    return {};
 }
 
 static void addAuthenticationItem(QComboBox *authCombo, MailTransport::Transport::EnumAuthenticationType::type authtype)
@@ -309,7 +309,7 @@ void ServerSieveSettings::slotFinished(const QVector<int> &testResult)
     using namespace MailTransport;
 
     if (!mServerTest->isNormalPossible() && !mServerTest->isSecurePossible()) {
-        KMessageBox::sorry(this, i18n("Unable to connect to the server, please verify the server address."));
+        KMessageBox::error(this, i18n("Unable to connect to the server, please verify the server address."));
     }
 
     ui->testInfo->show();
