@@ -15,6 +15,7 @@
 
 #include "sieveeditor_debug.h"
 #include <QVBoxLayout>
+#include <kwidgetsaddons_version.h>
 
 SieveEditorPageWidget::SieveEditorPageWidget(QWidget *parent)
     : QWidget(parent)
@@ -72,7 +73,7 @@ void SieveEditorPageWidget::loadScript(const KSieveUi::ManageSieveWidget::Script
     mSieveEditorWidget->setSieveImapAccountSettings(info.sieveImapAccountSettings);
     mSieveEditorWidget->setListOfIncludeFile(info.scriptList);
     mSieveEditorWidget->setReadOnly(true);
-    mSieveEditorWidget->wordWrap(SieveEditorGlobalConfig::self()->wrapText());
+    mSieveEditorWidget->setWordWrap(SieveEditorGlobalConfig::self()->wrapText());
     KManageSieve::SieveJob *job = KManageSieve::SieveJob::get(mCurrentURL);
     connect(job, &KManageSieve::SieveJob::result, this, &SieveEditorPageWidget::slotGetResult);
 }
@@ -162,8 +163,20 @@ bool SieveEditorPageWidget::needToSaveScript()
 {
     bool result = false;
     if (mIsNewScript) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const int resultQuestion = KMessageBox::warningTwoActionsCancel(this,
+                                                                        i18n("Script '%1' is new. Do you want to save it?", mCurrentURL.fileName()),
+                                                                        i18n("Save Script"),
+                                                                        KStandardGuiItem::save(),
+                                                                        KStandardGuiItem::discard());
+#else
         const int resultQuestion = KMessageBox::warningYesNoCancel(this, i18n("Script '%1' is new. Do you want to save it?", mCurrentURL.fileName()));
+#endif
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (resultQuestion == KMessageBox::ButtonCode::PrimaryAction) {
+#else
         if (resultQuestion == KMessageBox::Yes) {
+#endif
             uploadScript();
             result = true;
         } else if (resultQuestion == KMessageBox::Cancel) {
@@ -171,8 +184,20 @@ bool SieveEditorPageWidget::needToSaveScript()
         }
     } else {
         if (mSieveEditorWidget->isModified()) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            const int resultQuestion = KMessageBox::warningTwoActionsCancel(this,
+                                                                            i18n("Script '%1' was changed. Do you want to save it ?", mCurrentURL.fileName()),
+                                                                            i18n("Save Script"),
+                                                                            KStandardGuiItem::save(),
+                                                                            KStandardGuiItem::discard());
+#else
             const int resultQuestion = KMessageBox::warningYesNoCancel(this, i18n("Script '%1' was changed. Do you want to save it ?", mCurrentURL.fileName()));
+#endif
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (resultQuestion == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             if (resultQuestion == KMessageBox::Yes) {
+#endif
                 uploadScript();
                 result = true;
             } else if (resultQuestion == KMessageBox::Cancel) {
@@ -333,9 +358,9 @@ QString SieveEditorPageWidget::currentText() const
     return mSieveEditorWidget->script();
 }
 
-void SieveEditorPageWidget::wordWrap(bool state)
+void SieveEditorPageWidget::setWordWrap(bool state)
 {
-    mSieveEditorWidget->wordWrap(state);
+    mSieveEditorWidget->setWordWrap(state);
 }
 
 bool SieveEditorPageWidget::isWordWrap() const
