@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,9 +25,7 @@ SieveEditorTabWidget::SieveEditorTabWidget(KActionCollection *ac, QWidget *paren
     connect(this, &SieveEditorTabWidget::customContextMenuRequested, this, &SieveEditorTabWidget::slotTabContextMenuRequest);
 }
 
-SieveEditorTabWidget::~SieveEditorTabWidget()
-{
-}
+SieveEditorTabWidget::~SieveEditorTabWidget() = default;
 
 void SieveEditorTabWidget::slotTabContextMenuRequest(const QPoint &pos)
 {
