@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ SievePurposeMenuWidget::SievePurposeMenuWidget(QWidget *parentWidget, QObject *p
 {
 }
 
-SievePurposeMenuWidget::~SievePurposeMenuWidget()
-{
-}
+SievePurposeMenuWidget::~SievePurposeMenuWidget() = default;
 
 QByteArray SievePurposeMenuWidget::text()
 {
