@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ SieveServerSettings::SieveServerSettings(QObject *parent)
 {
 }
 
-SieveServerSettings::~SieveServerSettings()
-{
-}
+SieveServerSettings::~SieveServerSettings() = default;
 
 SieveServerSettings *SieveServerSettings::self()
 {
